==> chaosmesh-model-6.8.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMGCSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class JVMGCSpecFluent<A extends JVMGCSpecFluent<A>> extends BaseFluent<A>{
  public JVMGCSpecFluent() {
  }
  public JVMGCSpecFluent(JVMGCSpec instance) {
    instance = (instance != null ? instance : new JVMGCSpec());

    if (instance != null) {
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
    }
  }
  private Integer pid;
  private Integer port;
  public Integer getPid() {
    return this.pid;
  }
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  public boolean hasPid() {
    return this.pid != null;
  }
  public Integer getPort() {
    return this.port;
  }
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  public boolean hasPort() {
    return this.port != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMGCSpecFluent that = (JVMGCSpecFluent) o;
    if (!java.util.Objects.equals(pid, that.pid)) return false;

    if (!java.util.Objects.equals(port, that.port)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(pid,  port,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> chaosmesh-model-6.9.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMGCSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class JVMGCSpecFluent<A extends JVMGCSpecFluent<A>> extends BaseFluent<A>{
  public JVMGCSpecFluent() {
  }
  
  public JVMGCSpecFluent(JVMGCSpec instance) {
    this.copyInstance(instance);
  }
  private Integer pid;
  private Integer port;
  
  protected void copyInstance(JVMGCSpec instance) {
    instance = (instance != null ? instance : new JVMGCSpec());
  
    if (instance != null) {
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
        this.withPid(instance.getPid());
        this.withPort(instance.getPort());
      }
  }
  
  public Integer getPid() {
    return this.pid;
  }
  
  public A withPid(Integer pid) {
    this.pid=pid; return (A) this;
  }
  
  public boolean hasPid() {
    return this.pid != null;
  }
  
  public Integer getPort() {
    return this.port;
  }
  
  public A withPort(Integer port) {
    this.port=port; return (A) this;
  }
  
  public boolean hasPort() {
    return this.port != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    JVMGCSpecFluent that = (JVMGCSpecFluent) o;
    if (!java.util.Objects.equals(pid, that.pid)) return false;
  
    if (!java.util.Objects.equals(port, that.port)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(pid,  port,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (pid != null) { sb.append("pid:"); sb.append(pid + ","); }
    if (port != null) { sb.append("port:"); sb.append(port); }
    sb.append("}");
    return sb.toString();
  }
  

}
